@@ -29,6 +29,31 @@ residuals( estResult )
 
 print.default( estResult )
 
+# estimate the translog production function with a different order of inputs
+estResultOrder <- translogEst( yName = "qOutput",
+   xNames = c( "qLabor", "qVarInput", "land", "time" ),
+   data = germanFarms )
+print( estResultOrder )
+summary( estResultOrder )
+all.equal( residuals( estResult ), residuals( estResultOrder ) )
+
+# estimate the translog production function with a different order of inputs
+estResultOrder2 <- translogEst( yName = "qOutput",
+   xNames = c( "land", "qVarInput", "qLabor", "time" ),
+   data = germanFarms )
+print( estResultOrder2 )
+summary( estResultOrder2 )
+all.equal( residuals( estResult ), residuals( estResultOrder2 ) )
+
+# estimate the translog production function with a different order of inputs
+estResultOrder3 <- translogEst( yName = "qOutput",
+   xNames = c( "land", "qVarInput", "time", "qLabor" ),
+   data = germanFarms )
+print( estResultOrder3 )
+summary( estResultOrder3 )
+all.equal( residuals( estResult ), residuals( estResultOrder3 ) )
+
+
 ## testing translogEst with dataLogged = TRUE
 estResultLog <- translogEst( "qLogOutput", 
    xNames = c( "qLogLabor", "qLogLand", "qLogVarInput", "logTime" ),
@@ -148,6 +173,41 @@ summary( test )
 class( test ) <- NULL
 print( test )
 
+
+## testing translogProdFuncMargCost
+# generate (artificial) prices
+germanFarms$pLand <- 200 + 15 * germanFarms$time
+germanFarms$pTime <- 1
+
+# compute the marginal costs of producing the output
+margCost <- translogProdFuncMargCost( yNames = "qOutput",
+   xNames = c( "qLabor", "land", "qVarInput", "time" ),
+   wNames = c( "pLabor", "pLand", "pVarInput", "pTime" ),
+   data = germanFarms, coef = coef( estResult ) )
+print( margCost )
+
+# compute the marginal costs again with different order of inputs
+margCostOrder <- translogProdFuncMargCost( yNames = "qOutput",
+   xNames = c( "qLabor", "qVarInput", "land", "time" ),
+   wNames = c( "pLabor", "pVarInput", "pLand", "pTime" ),
+   data = germanFarms, coef = coef( estResultOrder ) )
+all.equal( margCost, margCostOrder )
+
+# compute the marginal costs again with different order of inputs
+margCostOrder2 <- translogProdFuncMargCost( yNames = "qOutput",
+   xNames = c( "land", "qVarInput", "qLabor", "time" ),
+   wNames = c( "pLand", "pVarInput", "pLabor", "pTime" ),
+   data = germanFarms, coef = coef( estResultOrder2 ) )
+all.equal( margCost, margCostOrder2 )
+
+# compute the marginal costs again with different order of inputs
+margCostOrder3 <- translogProdFuncMargCost( yNames = "qOutput",
+   xNames = c( "land", "qVarInput", "time", "qLabor" ),
+   wNames = c( "pLand", "pVarInput", "pTime", "pLabor" ),
+   data = germanFarms, coef = coef( estResultOrder3 ) )
+all.equal( margCost, margCostOrder3 )
+
+
 ## testing translogEst with one shifter
 germanFarms$tech <- exp( germanFarms$time )
 estResultShifter <- translogEst( "qOutput",
@@ -369,3 +429,75 @@ ggResShifterFacRan <- translogEst( "invest", c( "value", "capital" ), ggData,
    shifterNames = "decade", model = "random", random.method = "amemiya" )
 print( ggResShifterFacRan )
 print.default( ggResShifterFacRan )
+
+
+## translog ray production function
+# quantity of crop outputs
+germanFarms$qCrop <- germanFarms$vCrop / germanFarms$pOutput
+# quantity of animal outputs
+germanFarms$qAnimal <- germanFarms$vAnimal / germanFarms$pOutput
+
+# estimate a translog ray production function
+estResultRay <- translogRayEst( yNames = c( "qCrop", "qAnimal" ),
+   xNames = c( "qLabor", "land", "qVarInput" ),
+   data = germanFarms )
+print( estResultRay )
+summary( estResultRay )
+print.default( estResultRay )
+
+# different order of outputs
+estResultRay2 <- translogRayEst( yNames = c( "qAnimal", "qCrop" ),
+   xNames = c( "qLabor", "land", "qVarInput" ),
+   data = germanFarms )
+print( estResultRay2 )
+summary( estResultRay2 )
+all.equal( abs( coef( estResultRay2 )[ 6:15 ] ),
+   abs( coef( estResultRay )[ 6:15 ] ) )
+
+# different order of inputs
+estResultRay3 <- translogRayEst( yNames = c( "qCrop", "qAnimal" ),
+   xNames = c( "qVarInput", "qLabor", "land" ),
+   data = germanFarms )
+print( estResultRay3 )
+summary( estResultRay3 )
+all.equal( coef( estResultRay ), coef( estResultRay3 )[
+   c( 1, 3, 4, 2, 5, 10, 11, 7, 12, 13, 8, 14, 6, 9, 15 ) ],
+   check.attributes = FALSE )
+
+
+## testing translogRayDeriv
+tlRayDeriv <- translogRayDeriv( yNames = c( "qCrop", "qAnimal" ),
+   xNames = c( "qLabor", "land", "qVarInput" ),
+   data = germanFarms, coef = coef( estResultRay ) )
+print( tlRayDeriv )
+
+tlRayDeriv2 <- translogRayDeriv( yNames = c( "qAnimal", "qCrop" ),
+   xNames = c( "qLabor", "land", "qVarInput" ),
+   data = germanFarms, coef = coef( estResultRay2 ) )
+all.equal( tlRayDeriv, tlRayDeriv2[ , c( 1:3, 5, 4 ) ] )
+
+tlRayDeriv3 <- translogRayDeriv( yNames = c( "qCrop", "qAnimal" ),
+   xNames = c( "qVarInput", "qLabor", "land" ),
+   data = germanFarms, coef = coef( estResultRay3 ) )
+all.equal( tlRayDeriv, tlRayDeriv3[ , c( 2, 3, 1, 4, 5 ) ] )
+
+
+## testing translogProdFuncMargCost with a ray function
+# compute the marginal costs of producing the output
+margCostRay <- translogProdFuncMargCost( yNames = c( "qCrop", "qAnimal" ),
+   xNames = c( "qLabor", "land", "qVarInput" ),
+   wNames = c( "pLabor", "pLand", "pVarInput" ),
+   data = germanFarms, coef = coef( estResultRay ) )
+print( margCostRay )
+
+margCostRay2 <- translogProdFuncMargCost( yNames = c( "qAnimal", "qCrop" ),
+   xNames = c( "qLabor", "land", "qVarInput" ),
+   wNames = c( "pLabor", "pLand", "pVarInput" ),
+   data = germanFarms, coef = coef( estResultRay2 ) )
+all.equal( margCostRay, margCostRay2[ , c( 2:1 ) ] )
+
+margCostRay3 <- translogProdFuncMargCost( yNames = c( "qCrop", "qAnimal" ),
+   xNames = c( "qVarInput", "qLabor", "land" ),
+   wNames = c( "pVarInput", "pLabor", "pLand" ),
+   data = germanFarms, coef = coef( estResultRay3 ) )
+all.equal( margCostRay, margCostRay3 )
